summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-12-09 09:35:17 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-12-09 09:43:42 -0600
commit83283ff752edf7e4b6077b8a53ca0d278d0a4d64 (patch)
tree97762a272fcd977e6bf29b71db18aea916b31663
parent9d757479d19fae9a0769ec57076f4c49de3faf4d (diff)
downloadlibpng-83283ff752edf7e4b6077b8a53ca0d278d0a4d64.tar.gz
[libpng14] Bump version to 1.4.19beta01
-rw-r--r--CMakeLists.txt4
-rw-r--r--INSTALL4
-rw-r--r--LICENSE4
-rw-r--r--Makefile.am2
-rw-r--r--Makefile.in2
-rw-r--r--README12
-rwxr-xr-xconfigure24
-rw-r--r--configure.ac6
-rw-r--r--libpng-1.4.19beta01.txt (renamed from libpng-1.4.18.txt)8
-rw-r--r--libpng.318
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--png.h24
-rw-r--r--pngconf.h2
-rw-r--r--pngpriv.h2
-rw-r--r--pngrutil.c2
-rw-r--r--pngtest.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt12
-rwxr-xr-xscripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.cegcc2
-rw-r--r--scripts/makefile.linux2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/png32ce.def2
-rw-r--r--scripts/pngos2.def2
-rw-r--r--scripts/pngwin.def2
31 files changed, 82 insertions, 82 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 7334b114b..1860c56d0 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -33,7 +33,7 @@ enable_testing()
set(PNGLIB_MAJOR 1)
set(PNGLIB_MINOR 4)
-set(PNGLIB_RELEASE 18)
+set(PNGLIB_RELEASE 19)
set(PNGLIB_NAME libpng${PNGLIB_MAJOR}${PNGLIB_MINOR})
set(PNGLIB_VERSION ${PNGLIB_MAJOR}.${PNGLIB_MINOR}.${PNGLIB_RELEASE})
@@ -255,7 +255,7 @@ install(CODE ${PNG_CONFIG_INSTALL_CODE})
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 14.${PNGLIB_RELEASE}.1.4.18
+# VERSION 14.${PNGLIB_RELEASE}.1.4.19beta01
VERSION 14.${PNGLIB_RELEASE}.0
SOVERSION 14
CLEAN_DIRECT_OUTPUT 1)
diff --git a/INSTALL b/INSTALL
index 8df3fd9fc..2db193310 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
-Installing libpng version 1.4.18 - December 3, 2015
+Installing libpng version 1.4.19beta01 - December 9, 2015
On Unix/Linux and similar systems, you can simply type
@@ -46,7 +46,7 @@ to have access to the zlib.h and zconf.h include files that
correspond to the version of zlib that's installed.
You can rename the directories that you downloaded (they
-might be called "libpng-1.4.18" or "libpng14" and "zlib-1.2.3"
+might be called "libpng-1.4.19beta01" or "libpng14" and "zlib-1.2.3"
or "zlib123") so that you have directories called "zlib" and "libpng".
Your directory structure should look like this:
diff --git a/LICENSE b/LICENSE
index a724e20f9..f66fe8bda 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.4.18, December 3, 2015, are
+libpng versions 1.0.7, July 1, 2000, through 1.4.19beta01, December 9, 2015, are
Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, are
derived from libpng-1.0.6, and are distributed according to the same
disclaimer and license as libpng-1.0.6 with the following individuals
@@ -107,4 +107,4 @@ the additional disclaimers inserted at version 1.0.7.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-December 3, 2015
+December 9, 2015
diff --git a/Makefile.am b/Makefile.am
index 63a2e478d..829e3325e 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -79,7 +79,7 @@ EXTRA_DIST= \
${srcdir}/contrib/pngsuite/* \
${srcdir}/contrib/visupng/* \
$(TESTS) \
- example.c libpng-1.4.18.txt
+ example.c libpng-1.4.19beta01.txt
CLEANFILES= pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
libpng.sym
diff --git a/Makefile.in b/Makefile.in
index 07003d2aa..db3b04392 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -628,7 +628,7 @@ EXTRA_DIST = \
${srcdir}/contrib/pngsuite/* \
${srcdir}/contrib/visupng/* \
$(TESTS) \
- example.c libpng-1.4.18.txt
+ example.c libpng-1.4.19beta01.txt
CLEANFILES = pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
libpng.sym
diff --git a/README b/README
index 8f29419f9..d7f03aa57 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.4.18 - December 3, 2015 (shared library 14.0)
+README for libpng version 1.4.19beta01 - December 9, 2015 (shared library 14.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
@@ -187,9 +187,9 @@ Files in this distribution:
makefile.std => Generic UNIX makefile (cc, creates static
libpng.a)
makefile.elf => Linux/ELF makefile symbol versioning,
- (gcc, creates libpng14.so.14.1.4.18)
+ (gcc, creates libpng14.so.14.1.4.19beta01)
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng14.so.14.1.4.18)
+ (gcc, creates libpng14.so.14.1.4.19beta01)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -211,12 +211,12 @@ Files in this distribution:
makefile.openbsd => OpenBSD makefile
makefile.sgi => Silicon Graphics IRIX (cc, creates static lib)
makefile.sggcc => Silicon Graphics
- (gcc, creates libpng14.so.14.1.4.18)
+ (gcc, creates libpng14.so.14.1.4.19beta01)
makefile.sunos => Sun makefile
makefile.solaris => Solaris 2.X makefile
- (gcc, creates libpng14.so.14.1.4.18)
+ (gcc, creates libpng14.so.14.1.4.19beta01)
makefile.so9 => Solaris 9 makefile
- (gcc, creates libpng14.so.14.1.4.18)
+ (gcc, creates libpng14.so.14.1.4.19beta01)
makefile.32sunu => Sun Ultra 32-bit makefile
makefile.64sunu => Sun Ultra 64-bit makefile
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
diff --git a/configure b/configure
index 7cd288bff..07a975cd2 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
#! /bin/sh
# Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for libpng 1.4.18.
+# Generated by GNU Autoconf 2.69 for libpng 1.4.19beta01.
#
# Report bugs to <png-mng-implement@lists.sourceforge.net>.
#
@@ -590,8 +590,8 @@ MAKEFLAGS=
# Identity of this package.
PACKAGE_NAME='libpng'
PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.4.18'
-PACKAGE_STRING='libpng 1.4.18'
+PACKAGE_VERSION='1.4.19beta01'
+PACKAGE_STRING='libpng 1.4.19beta01'
PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
PACKAGE_URL=''
@@ -1333,7 +1333,7 @@ if test "$ac_init_help" = "long"; then
# Omit some internal or obsolete options to make the list less imposing.
# This message is too long to be a string in the A/UX 3.1 sh.
cat <<_ACEOF
-\`configure' configures libpng 1.4.18 to adapt to many kinds of systems.
+\`configure' configures libpng 1.4.19beta01 to adapt to many kinds of systems.
Usage: $0 [OPTION]... [VAR=VALUE]...
@@ -1403,7 +1403,7 @@ fi
if test -n "$ac_init_help"; then
case $ac_init_help in
- short | recursive ) echo "Configuration of libpng 1.4.18:";;
+ short | recursive ) echo "Configuration of libpng 1.4.19beta01:";;
esac
cat <<\_ACEOF
@@ -1520,7 +1520,7 @@ fi
test -n "$ac_init_help" && exit $ac_status
if $ac_init_version; then
cat <<\_ACEOF
-libpng configure 1.4.18
+libpng configure 1.4.19beta01
generated by GNU Autoconf 2.69
Copyright (C) 2012 Free Software Foundation, Inc.
@@ -1943,7 +1943,7 @@ cat >config.log <<_ACEOF
This file contains any messages produced by compilers while
running configure, to aid debugging if configure makes a mistake.
-It was created by libpng $as_me 1.4.18, which was
+It was created by libpng $as_me 1.4.19beta01, which was
generated by GNU Autoconf 2.69. Invocation command line was
$ $0 $@
@@ -2806,7 +2806,7 @@ fi
# Define the identity of the package.
PACKAGE='libpng'
- VERSION='1.4.18'
+ VERSION='1.4.19beta01'
cat >>confdefs.h <<_ACEOF
@@ -2923,10 +2923,10 @@ fi
-PNGLIB_VERSION=1.4.18
+PNGLIB_VERSION=1.4.19beta01
PNGLIB_MAJOR=1
PNGLIB_MINOR=4
-PNGLIB_RELEASE=18
+PNGLIB_RELEASE=19
@@ -13615,7 +13615,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
# report actual input values of CONFIG_FILES etc. instead of their
# values after options handling.
ac_log="
-This file was extended by libpng $as_me 1.4.18, which was
+This file was extended by libpng $as_me 1.4.19beta01, which was
generated by GNU Autoconf 2.69. Invocation command line was
CONFIG_FILES = $CONFIG_FILES
@@ -13681,7 +13681,7 @@ _ACEOF
cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
ac_cs_version="\\
-libpng config.status 1.4.18
+libpng config.status 1.4.19beta01
configured by $0, generated by GNU Autoconf 2.69,
with options \\"\$ac_cs_config\\"
diff --git a/configure.ac b/configure.ac
index 20de2386f..f5e8ec28b 100644
--- a/configure.ac
+++ b/configure.ac
@@ -16,17 +16,17 @@ dnl should not be necessary to regenerate configure if the time
dnl stamps are correct
AC_PREREQ(2.59)
-AC_INIT([libpng], [1.4.18], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.4.19beta01], [png-mng-implement@lists.sourceforge.net])
AM_INIT_AUTOMAKE
dnl stop configure from automagically running automake
AM_MAINTAINER_MODE
dnl Version number stuff here:
-PNGLIB_VERSION=1.4.18
+PNGLIB_VERSION=1.4.19beta01
PNGLIB_MAJOR=1
PNGLIB_MINOR=4
-PNGLIB_RELEASE=18
+PNGLIB_RELEASE=19
dnl End of version number stuff
diff --git a/libpng-1.4.18.txt b/libpng-1.4.19beta01.txt
index 3fa478c1a..e0f42ee81 100644
--- a/libpng-1.4.18.txt
+++ b/libpng-1.4.19beta01.txt
@@ -1,6 +1,6 @@
libpng.txt - A description on how to use and modify libpng
- libpng version 1.4.18 - December 3, 2015
+ libpng version 1.4.19beta01 - December 9, 2015
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.4.18 - December 3, 2015
+ libpng versions 0.97, January 1998, through 1.4.19beta01 - December 9, 2015
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -907,7 +907,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.4.18, not all possible expansions are supported.
+As of libpng version 1.4.19beta01, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -3298,7 +3298,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.18 are Y2K compliant. It is my belief that earlier
+upward through 1.4.19beta01 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index 95bcba1f8..d86e36c90 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "December 3, 2015"
+.TH LIBPNG 3 "December 9, 2015"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.18
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.19beta01
.SH SYNOPSIS
\fB
#include <png.h>\fP
@@ -442,7 +442,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng.txt - A description on how to use and modify libpng
- libpng version 1.4.18 - December 3, 2015
+ libpng version 1.4.19beta01 - December 9, 2015
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -453,7 +453,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.4.18 - December 3, 2015
+ libpng versions 0.97, January 1998, through 1.4.19beta01 - December 9, 2015
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -1349,7 +1349,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.4.18, not all possible expansions are supported.
+As of libpng version 1.4.19beta01, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -3740,7 +3740,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.18 are Y2K compliant. It is my belief that earlier
+upward through 1.4.19beta01 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
@@ -3893,7 +3893,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.4.18 - December 3, 2015:
+Libpng version 1.4.19beta01 - December 9, 2015:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -3918,7 +3918,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.4.18, December 3, 2015, are
+libpng versions 1.0.7, July 1, 2000, through 1.4.19beta01, December 9, 2015, are
Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, are
derived from libpng-1.0.6, and are distributed according to the same
disclaimer and license as libpng-1.0.6 with the following individuals
@@ -4015,7 +4015,7 @@ the additional disclaimers inserted at version 1.0.7.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-December 3, 2015
+December 9, 2015
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 32189ab25..8c84c1e9c 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "December 3, 2015"
+.TH LIBPNGPF 3 "December 9, 2015"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.18
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.19beta01
(private functions)
.SH SYNOPSIS
\fB#include <png.h>
diff --git a/png.5 b/png.5
index 76a327ba6..4ce3bbddc 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "December 3, 2015"
+.TH PNG 5 "December 9, 2015"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 37286404c..fcd12e1ec 100644
--- a/png.c
+++ b/png.c
@@ -17,7 +17,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_18 Your_png_h_is_not_version_1_4_18;
+typedef version_1_4_19beta01 Your_png_h_is_not_version_1_4_19beta01;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -558,13 +558,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
#ifdef __STDC__
return ((png_charp) PNG_STRING_NEWLINE \
- "libpng version 1.4.18 - December 3, 2015" PNG_STRING_NEWLINE \
+ "libpng version 1.4.19beta01 - December 9, 2015" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2015 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE);
#else
- return ((png_charp) "libpng version 1.4.18 - December 3, 2015\
+ return ((png_charp) "libpng version 1.4.19beta01 - December 9, 2015\
Copyright (c) 1998-2015 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
diff --git a/pngconf.h b/pngconf.h
index 08fdb7128..35d03269b 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.4.18, December 3, 2015
+ * libpng version 1.4.19beta01, December 9, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpriv.h b/pngpriv.h
index 91e534473..7142b1d0a 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
/* pngpriv.h - private declarations for use inside libpng
*
- * libpng version 1.4.18 - December 3, 2015
+ * libpng version 1.4.19beta01 - December 9, 2015
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngrutil.c b/pngrutil.c
index b0b9c2f58..de89becfb 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -1,7 +1,7 @@
/* pngrutil.c - utilities to read a PNG file
*
- * Last changed in libpng 1.4.18 [December 3, 2015]
+ * Last changed in libpng 1.4.18 [December 9, 2015]
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngtest.c b/pngtest.c
index d82ecbe12..66e2380c8 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1737,4 +1737,4 @@ main(int argc, char *argv[])
}
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_18 your_png_h_is_not_version_1_4_18;
+typedef version_1_4_19beta01 your_png_h_is_not_version_1_4_19beta01;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index c6ea23457..def93551d 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.4.18 - December 3, 2015
+libpng version 1.4.19beta01 - December 9, 2015
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index d3894e55d..aae13536f 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source and build
*
- * libpng version 1.4.18 - December 3, 2015
+ * libpng version 1.4.19beta01 - December 9, 2015
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index e7081d5d5..73d5c73d8 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,8 +1,8 @@
-Makefiles for libpng version 1.4.18 - December 3, 2015
+Makefiles for libpng version 1.4.19beta01 - December 9, 2015
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng14.so.14.1.4.18)
+ (gcc, creates libpng14.so.14.1.4.19beta01)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@ Makefiles for libpng version 1.4.18 - December 3, 2015
makefile.dec => DEC Alpha UNIX makefile
makefile.dj2 => DJGPP 2 makefile
makefile.elf => Linux/ELF makefile symbol versioning,
- (gcc, creates libpng14.so.14.1.4.18)
+ (gcc, creates libpng14.so.14.1.4.19beta01)
makefile.freebsd => FreeBSD makefile
makefile.gcc => Generic gcc makefile
makefile.hpgcc => HPUX makefile using gcc
@@ -36,12 +36,12 @@ Makefiles for libpng version 1.4.18 - December 3, 2015
makefile.os2 => OS/2 Makefile (gcc and emx, requires pngos2.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng14.so.14.1.4.18)
+ creates libpng14.so.14.1.4.19beta01)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng14.so.14.1.4.18)
+ creates libpng14.so.14.1.4.19beta01)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng14.so.14.1.4.18)
+ creates libpng14.so.14.1.4.19beta01)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index cece9d749..3eb29a2c2 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.4.18
+version=1.4.19beta01
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 9dd36d233..a50bb0ed3 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng14
Name: libpng
Description: Loads and saves PNG files
-Version: 1.4.18
+Version: 1.4.19beta01
Libs: -L${libdir} -lpng14
Cflags: -I${includedir}
diff --git a/scripts/makefile.cegcc b/scripts/makefile.cegcc
index 148648da6..090429852 100644
--- a/scripts/makefile.cegcc
+++ b/scripts/makefile.cegcc
@@ -23,7 +23,7 @@
VERMAJ = 1
VERMIN = 4
-VERMIC = 18
+VERMIC = 19
VER = $(VERMAJ).$(VERMIN).$(VERMIC)
NAME = libpng
PACKAGE = $(NAME)-$(VER)
diff --git a/scripts/makefile.linux b/scripts/makefile.linux
index 414d9eb1e..d45504cc7 100644
--- a/scripts/makefile.linux
+++ b/scripts/makefile.linux
@@ -10,7 +10,7 @@
# Library name:
LIBNAME = libpng14
PNGMAJ = 14
-RELEASE = 18
+RELEASE = 19
# Shared library names:
LIBSO=$(LIBNAME).so
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 94df3d5c2..6c88c2b17 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng14
LIB= png14
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.4.18
+SHLIB_MINOR= 1.4.19beta01
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 1cd0979ce..331df9057 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 3
-SHLIB_MINOR= 1.4.18
+SHLIB_MINOR= 1.4.19beta01
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index b86bf28a4..b149f9cc2 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.4.18
+SHLIB_MINOR= 1.4.19beta01
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/png32ce.def b/scripts/png32ce.def
index 83a099a17..a51fa9d12 100644
--- a/scripts/png32ce.def
+++ b/scripts/png32ce.def
@@ -15,7 +15,7 @@ LIBRARY lpngce
png_get_int_32
EXPORTS
-;Version 1.4.18
+;Version 1.4.19beta01
png_build_grayscale_palette @1
; png_check_sig @2
png_chunk_error @3
diff --git a/scripts/pngos2.def b/scripts/pngos2.def
index f4ce091a0..27b401084 100644
--- a/scripts/pngos2.def
+++ b/scripts/pngos2.def
@@ -2,7 +2,7 @@
; PNG.LIB module definition file for OS/2
;----------------------------------------
-; Version 1.4.18
+; Version 1.4.19beta01
LIBRARY PNG
DESCRIPTION "PNG image compression library for OS/2"
diff --git a/scripts/pngwin.def b/scripts/pngwin.def
index 57d2c75bd..e799157e4 100644
--- a/scripts/pngwin.def
+++ b/scripts/pngwin.def
@@ -5,7 +5,7 @@
LIBRARY
EXPORTS
-;Version 1.4.18
+;Version 1.4.19beta01
png_build_grayscale_palette
png_chunk_error
png_chunk_warning
diff --git a/png.h b/png.h
index 04d171913..1c0ebe94d 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.4.18, December 3, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.4.18, December 3, 2015: Glenn
* See also "Contributing Authors", below.
*/
@@ -24,7 +24,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.0.7, July 1, 2000, through 1.4.18, December 3, 2015, are
* Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same
* disclaimer and license as libpng-1.0.6 with the following individuals
@@ -207,13 +207,13 @@
* Y2K compliance in libpng:
* =========================
*
- * December 3, 2015
+ * December 9, 2015
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.4.18 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -269,9 +269,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.18"
+#define PNG_LIBPNG_VER_STRING "1.4.19beta01"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.4.18 - December 3, 2015\n"
+ " libpng version 1.4.19beta01 - December 9, 2015\n"
#define PNG_LIBPNG_VER_SONUM 14
#define PNG_LIBPNG_VER_DLLNUM 14
@@ -279,12 +279,12 @@
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
#define PNG_LIBPNG_VER_MAJOR 1
#define PNG_LIBPNG_VER_MINOR 4
-#define PNG_LIBPNG_VER_RELEASE 18
+#define PNG_LIBPNG_VER_RELEASE 19
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 0
+#define PNG_LIBPNG_VER_BUILD 01
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -301,7 +301,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_STABLE
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -309,7 +309,7 @@
* version 1.0.0 was mis-numbered 100 instead of 10000). From
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release
*/
-#define PNG_LIBPNG_VER 10418 /* 1.4.18 */
+#define PNG_LIBPNG_VER 10419 /* 1.4.19 */
#ifndef PNG_VERSION_INFO_ONLY
/* Include the compression library's header */
@@ -1378,7 +1378,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_4_18;
+typedef png_structp version_1_4_19beta01;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.4.18, December 3, 2015
+ * libpng version 1.4.19beta01, December 9, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.4.18, December 3, 2015: Glenn
+ * libpng versions 0.97, January 1998, through 1.4.19beta01, December 9, 2015: Glenn
* See also "Contributing Authors", below.
*/
@@ -24,7 +24,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.0.7, July 1, 2000, through 1.4.18, December 3, 2015, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.4.19beta01, December 9, 2015, are
* Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same
@@ -207,13 +207,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.4.18 are Y2K compliant. It is my belief that earlier
+ * upward through 1.4.19beta01 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*